==> haskell-interpolate-0.2.1-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-CUBHTIntBaECO6Tg7Pt8i0
key:                  interpolate-0.2.1-CUBHTIntBaECO6Tg7Pt8i0
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  a1643a308404fd2b0c7d33286c9486a9
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-8.10.3/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/interpolate-0.2.1
hs-libraries:         HSinterpolate-0.2.1-CUBHTIntBaECO6Tg7Pt8i0
depends:
    base-4.14.1.0 haskell-src-meta-0.8.5-24R0hsZuoyo5hywLYss5XF
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-4aKQV7OpPgbJQClIlYWQgL
key:                  interpolate-0.2.1-4aKQV7OpPgbJQClIlYWQgL
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  c6d5ca5040554d685a9bba95ba08d5bb
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-8.10.3/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/interpolate-0.2.1
hs-libraries:         HSinterpolate-0.2.1-4aKQV7OpPgbJQClIlYWQgL
depends:
    base-4.14.1.0 haskell-src-meta-0.8.5-8Kn692Di0IiFVo9RAwbL3l
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
